package com.xinelu.manage.service.goodsCategory;


import com.xinelu.common.core.domain.AjaxResult;
import com.xinelu.manage.domain.goodsCategory.GoodsCategory;
import com.xinelu.manage.vo.goodsCategory.GoodsCategoryVO;
import com.xinelu.manage.vo.goodsCategory.ParentCategory;

import java.util.List;

/**
 * 商品分类信息Service接口
 *
 * @author xinyilu
 * @date 2022-10-17
 */
public interface IGoodsCategoryService {
    /**
     * 查询商品分类信息
     *
     * @param id 商品分类信息主键
     * @return 商品分类信息
     */
    ParentCategory selectGoodsCategoryById(Long id);

    /**
     * 查询商品分类信息列表
     *
     * @param goodsCategory 商品分类信息
     * @return 商品分类信息集合
     */
    List<GoodsCategory> selectGoodsCategoryList(GoodsCategory goodsCategory);

    /**
     * 新增商品分类信息
     *
     * @param goodsCategory 商品分类信息
     * @return 结果
     */
    AjaxResult insertGoodsCategory(GoodsCategory goodsCategory);

    /**
     * 修改商品分类信息
     *
     * @param goodsCategory 商品分类信息
     * @return 结果
     */
    AjaxResult updateGoodsCategory(GoodsCategory goodsCategory);

    /**
     * 批量删除商品分类信息
     *
     * @param ids 需要删除的商品分类信息主键集合
     * @return 结果
     */
    AjaxResult deleteGoodsCategoryByIds(Long[] ids);

    /**
     * 删除商品分类信息信息
     *
     * @param id 商品分类信息主键
     * @return 结果
     */
    int deleteGoodsCategoryById(Long id);

    /**
     * 查询所有的分类，父子关系
     *
     * @param parentId 分类父ID
     * @return 所有的分类，父子关系
     */
    List<GoodsCategoryVO> listAllChildren(String parentId);

    /**
     * 获取分类树
     *
     * @return 分类树
     */
    List<GoodsCategoryVO> categoryTree();


}
